@@ -372,7 +372,7 @@ void KMixWindow::saveBaseConfig()
 	// Using it again, as internal behaviour has changed with KDE4
 	config.writeEntry("Visible", isVisible());
 	config.writeEntry("Menubar", _actionShowMenubar->isChecked());
-	config.writeEntry("Soundmenu.Mixers", GlobalConfig::instance().getMixersForSoundmenu().toList());
+        config.writeEntry("Soundmenu.Mixers", GlobalConfig::instance().getMixersForSoundmenu().values());
 
 	config.writeEntry("DefaultCardOnStart", m_defaultCardOnStart);
 	config.writeEntry("ConfigVersion", KMIX_CONFIG_VERSION);
@@ -445,7 +445,7 @@ void KMixWindow::saveVolumes()
 	saveVolumes(QString());
 }
 
-void KMixWindow::saveVolumes(QString postfix)
+void KMixWindow::saveVolumes(const QString &postfix)
 {
 	const QString& kmixctrlRcFilename = getKmixctrlRcFilename(postfix);
 	KConfig *cfg = new KConfig(kmixctrlRcFilename);
@@ -463,7 +463,7 @@ void KMixWindow::saveVolumes(QString postfix)
 	<< "Volume configuration saved";
 }
 
-QString KMixWindow::getKmixctrlRcFilename(QString postfix)
+QString KMixWindow::getKmixctrlRcFilename(const QString &postfix)
 {
 	QString kmixctrlRcFilename("kmixctrlrc");
 	if (!postfix.isEmpty())
@@ -678,7 +678,7 @@ void KMixWindow::recreateGUI(bool saveConfig, const QString& mixerId, bool force
 				if (guiprof==nullptr)
 				{
 					qCWarning(KMIX_LOG) << "Cannot load profile" << profileId;
-					if (profileId.startsWith("MPRIS2."))
+					if (profileId.startsWith(QLatin1String("MPRIS2.")))
 					{
 						profileId = "MPRIS2.default";
 						qCDebug(KMIX_LOG) << "For MPRIS2 falling back to" << profileId;
